@@ -1,4 +1,4 @@
-## ----setup, include=FALSE-----------------------------------------------------
+## ----setup, include=FALSE-------------------------------------------
 library(INLA)
 inla.setOption(smtp='taucs')
 inla.setOption(num.threads="1:1")
@@ -8,13 +8,16 @@ knitr::opts_chunk$set(fig.path="figures/old-faq/")
 set.seed(123)
 source("render_toc.R")
 
-## ----toc, echo=FALSE----------------------------------------------------------
+## ----toc, echo=FALSE------------------------------------------------
 render_toc("old-faq.Rmd")
 
-## ---- eval=FALSE--------------------------------------------------------------
+## -------------------------------------------------------------------
+inla.setOption(inla.mode="classic")
+
+## ----eval=FALSE-----------------------------------------------------
 #      expression: statement; statement; ...; return(value)
 
-## ----eval=FALSE---------------------------------------------------------------
+## ----eval=FALSE-----------------------------------------------------
 #      prior.expression = "expression:
 #          a = 1;
 #          b = 0.1;
@@ -24,10 +27,10 @@ render_toc("old-faq.Rmd")
 #          log_jacobian = log_precision;
 #          return(logdens + log_jacobian);"
 
-## ----eval=FALSE---------------------------------------------------------------
+## ----eval=FALSE-----------------------------------------------------
 #      table: x_1 ... x_n y_1 ... y_n
 
-## -----------------------------------------------------------------------------
+## -------------------------------------------------------------------
 ## the loggamma-prior
 prior.function = function(log_precision) {
     a = 1;
@@ -74,9 +77,9 @@ r3 = inla(y~1, data = data.frame(y),
           control.family = list(hyper = list(
 		                        prec = list(prior = prior.table))))
 
-print(round(c(r1$mlik[1], r2$mlik[1], r3$mlik[1]), dig=3))
+print(round(c(r1$mlik[1], r2$mlik[1], r3$mlik[1]), digits=3))
 
-## -----------------------------------------------------------------------------
+## -------------------------------------------------------------------
 n = 100
 z = rnorm(n)
 eta = 1 + 0.1*z
@@ -100,7 +103,7 @@ rrr = inla(y ~ 1 + z,  data = data.frame(y, z), family = "binomial", Ntrials = r
         control.family = list(control.link = list(model="cloglog")), 
 		control.predictor = list(compute=TRUE))        
 
-## -----------------------------------------------------------------------------
+## -------------------------------------------------------------------
 n = 100
 n.pred = 10
 y = arima.sim(n=n, model=list(ar=0.9))
@@ -111,10 +114,10 @@ formula = yy ~ f(i, model="ar1")
 r = inla(formula, data = data.frame(i,yy),
         control.family = list(initial = 10, fixed=TRUE)) ## no observational noise
 
-## -----------------------------------------------------------------------------
+## -------------------------------------------------------------------
 r$summary.random$i[(n+1):N, c("mean", "sd") ]
 
-## ----plot=TRUE----------------------------------------------------------------
+## ----plot=TRUE------------------------------------------------------
 ## simple poisson regression
 n = 100
 x = sort(runif(n))
@@ -135,7 +138,7 @@ r = inla(y ~ 1 + x,  family = "poisson",
 plot(exp(eta),type ="l")
 points(r$summary.fitted.values$mean, pch=19)
 
-## ----plot=T-------------------------------------------------------------------
+## ----plot=T---------------------------------------------------------
 n2 = n %/% 2L
 Y = matrix(NA, n, 2)
 Y[1:n2, 1] = y[1:n2]
@@ -151,7 +154,7 @@ r = inla(Y ~ 1 + x,  family = c("poisson", "nbinomial"),
 plot(exp(eta),type ="l")
 points(r$summary.fitted.values$mean, pch=19)
 
-## -----------------------------------------------------------------------------
+## -------------------------------------------------------------------
 ## Load the data
 data(Tokyo)
 summary(Tokyo)
@@ -193,73 +196,80 @@ for(i in 1:366) {
 }
 plot(fitted.values.mean)
 
-## ---- eval=FALSE--------------------------------------------------------------
+## ----eval=FALSE-----------------------------------------------------
 #  4
 #  1 2 3 4
 #  2 0
 #  3 1 1
 #  4 1 1
 
-## ----plot=TRUE,fig.width=2,fig.align='center'---------------------------------
-g = inla.read.graph("4 1 2 3 4 2 0 3 1 1 4 1 1")
-plot(g)
+## ----plot=TRUE,fig.width=2,fig.align='center'-----------------------
+if (requireNamespace("Rgraphviz") && requireNamespace("graph")) {
+  g = inla.read.graph("4 1 2 3 4 2 0 3 1 1 4 1 1")
+  tryCatch(
+    plot(g),
+    error = function(e) {
+      message("Rgraphviz plotting doesn't seem to work on this installation.")
+    }
+  )
+}
 
-## ----eval=FALSE---------------------------------------------------------------
+## ----eval=FALSE-----------------------------------------------------
 #  "4 1 2 3 4  2 0 3 1 1 4 1 1"
 
-## ----eval=FALSE---------------------------------------------------------------
+## ----eval=FALSE-----------------------------------------------------
 #  formula = y ~ f(idx, model = "besag", graph = "graph.dat")
 
-## ----eval=FALSE---------------------------------------------------------------
+## ----eval=FALSE-----------------------------------------------------
 #  formula = y ~ f(idx, model = "besag", graph = "4 1 2 3 4  2 0 3 1 1 4 1 1")
 
-## -----------------------------------------------------------------------------
+## -------------------------------------------------------------------
 C = matrix(c(1, 0, 1, 1, 0, 1, 0, 0, 1, 0, 1, 0, 1, 0, 0, 1),4,4)
 C
 
-## -----------------------------------------------------------------------------
+## -------------------------------------------------------------------
 C.sparse= inla.as.sparse(C)
 C.sparse
 
-## -----------------------------------------------------------------------------
+## -------------------------------------------------------------------
 str(g)
 
-## ----eval=FALSE---------------------------------------------------------------
+## ----eval=FALSE-----------------------------------------------------
 #  formula = y ~ x + f(k, model= <some model>)
 
-## ----eval=F-------------------------------------------------------------------
+## ----eval=F---------------------------------------------------------
 #  control.fixed = list(expand.factor.strategy = "inla")
 
-## -----------------------------------------------------------------------------
+## -------------------------------------------------------------------
 r = inla(y ~ 1 + x, data = data.frame(y=1:3, x=factor(c("a","b","c"))))
 as.matrix(r$model.matrix)
 
-## -----------------------------------------------------------------------------
+## -------------------------------------------------------------------
 r = inla(y ~ 1 + x, data = data.frame(y=1:3,x=factor(c("a","b","c"))), 
          control.fixed = list(expand.factor.strategy="inla"))
 as.matrix(r$model.matrix)
 
-## -----------------------------------------------------------------------------
+## -------------------------------------------------------------------
 r = inla(y ~ 1 + x, data = data.frame(y=1:3,x=factor(c("a","b",NA))), 
          control.fixed = list(expand.factor.strategy="inla"))
 as.matrix(r$model.matrix)
 
-## ----eval=FALSE---------------------------------------------------------------
+## ----eval=FALSE-----------------------------------------------------
 #  control.compute=list(cpo=TRUE)
 
-## ----eval=FALSE---------------------------------------------------------------
+## ----eval=FALSE-----------------------------------------------------
 #  improved.result = inla.cpo(result)
 
-## ----eval=FALSE---------------------------------------------------------------
+## ----eval=FALSE-----------------------------------------------------
 #  r = inla(..., inla.call = "submit")
 
-## ----eval=FALSE---------------------------------------------------------------
+## ----eval=FALSE-----------------------------------------------------
 #  inla.qstat()
 
-## ----eval=FALSE---------------------------------------------------------------
+## ----eval=FALSE-----------------------------------------------------
 #  r = inla.qget(r)
 
-## -----------------------------------------------------------------------------
+## -------------------------------------------------------------------
 ## A simple model
 n = 100
 a = rnorm(n)
@@ -295,7 +305,7 @@ lc1.1 = 2 * r$summary.fixed["a", "mean"] + 3 * r$summary.fixed["b",
 lc1.2= r$summary.lincomb.derived$mean
 print(round(c(lc1.1 = lc1.1, lc1.2 = lc1.2), dig=3))
 
-## -----------------------------------------------------------------------------
+## -------------------------------------------------------------------
 ## let wa and wb be vectors, and we want to compute the marginals for
 ## beta_a * wa[i] + beta_b * wb[i], for i=1..m. this is done
 ## conveniently as follows
@@ -312,13 +322,13 @@ r = inla(formula, data = data.frame(a,b,y),
         control.family = list(initial=10, fixed=TRUE))
 print(round(r$summary.lincomb.derived, dig=3))
 
-## ----eval=FALSE---------------------------------------------------------------
+## ----eval=FALSE-----------------------------------------------------
 #  control.inla = list(lincomb.derived.correlation.matrix = TRUE)
 
-## ----eval=FALSE---------------------------------------------------------------
+## ----eval=FALSE-----------------------------------------------------
 #  result$misc$lincomb.derived.correlation.matrix
 
-## -----------------------------------------------------------------------------
+## -------------------------------------------------------------------
 n = 100
 nPred = 10
 phi = 0.9
@@ -344,7 +354,7 @@ r = inla(formula,  data = data.frame(Y, time),
 
 print(round(r$misc$lincomb.derived.correlation.matrix,dig=3))
 
-## -----------------------------------------------------------------------------
+## -------------------------------------------------------------------
 n = 100
 u = rnorm(n)
 eta = 1 + u
@@ -359,7 +369,7 @@ result = inla(y ~ 1 + f(idx, model="iid",
 	          Ntrials = 1)
 summary(result)
 
-## -----------------------------------------------------------------------------
+## -------------------------------------------------------------------
 ## simple example
 set.seed(12345L)
 sd.data = 1
@@ -494,21 +504,21 @@ summary(r.new.b)
 ## The version r.new.b seems faster than r.new.a for more complex models with one or more spde-terms
 
 
-## -----------------------------------------------------------------------------
+## -------------------------------------------------------------------
 inla.list.models()
 
-## ----eval=FALSE---------------------------------------------------------------
+## ----eval=FALSE-----------------------------------------------------
 #  y = a + b*w + ...
 
-## ----eval=FALSE---------------------------------------------------------------
+## ----eval=FALSE-----------------------------------------------------
 #  f(idx, model="iid2d", n=2*m, ...)
 
-## ----eval=FALSE---------------------------------------------------------------
+## ----eval=FALSE-----------------------------------------------------
 #  idx = 1:m
 #  idx.copy = m + 1:m
 #  formula = y ~  f(idx, model="iid2d", n=2*m) + f(idx.copy, w, copy="idx") + ....
 
-## -----------------------------------------------------------------------------
+## -------------------------------------------------------------------
 n=1000
 i=1:n
 j = i
@@ -520,22 +530,22 @@ formula = y ~ f(i, model="iid",initial=0, fixed=T) +
 r = inla(formula, data = data.frame(i,j,w,y))
 summary(r)
 
-## ----eval=FALSE---------------------------------------------------------------
+## ----eval=FALSE-----------------------------------------------------
 #  beta = low + (high-low)*exp(beta.local)/(1+exp(beta.local))
 
-## ----eval=FALSE---------------------------------------------------------------
+## ----eval=FALSE-----------------------------------------------------
 #  f(idx, model = ..,  replicate = r)
 
-## ----eval=FALSE---------------------------------------------------------------
+## ----eval=FALSE-----------------------------------------------------
 #  i = 1:n
 #  formula = y ~  f(i, model = "iid") + ...
 
-## ----eval=FALSE---------------------------------------------------------------
+## ----eval=FALSE-----------------------------------------------------
 #  i = rep(1,n)
 #  r = 1:n
 #  formula = y ~  f(i, model="iid", replicate = r) + ...
 
-## -----------------------------------------------------------------------------
+## -------------------------------------------------------------------
 n = 100
 y1 = arima.sim(n=n, model=list(ar=c(0.9)))+10
 y2 = arima.sim(n=n, model=list(ar=c(0.9)))+20
@@ -551,10 +561,10 @@ result = inla(formula, family = "gaussian",
               control.family = list(initial = 12, fixed=TRUE))
 summary(result)
 
-## ----eval=FALSE---------------------------------------------------------------
+## ----eval=FALSE-----------------------------------------------------
 #  y ~ a + 1
 
-## -----------------------------------------------------------------------------
+## -------------------------------------------------------------------
 ##  Simple linear regression with observations with two different
 ##  variances.
 n = 100
@@ -578,7 +588,7 @@ result = inla(
                             list()))
 summary(result)
 
-## -----------------------------------------------------------------------------
+## -------------------------------------------------------------------
 ## Simple example with two types of likelihoods
 n = 10
 N = 2*n
@@ -626,7 +636,7 @@ result = inla(formula,
         E = E, Ntrials = Ntrials)
 summary(result)
 
-## ----eval=FALSE---------------------------------------------------------------
+## ----eval=FALSE-----------------------------------------------------
 #  X = numeric(N)
 #  X[1:n] = x
 #  X[1:n + n] = NA
@@ -637,7 +647,7 @@ summary(result)
 #  
 #  formula = Y  ~ X + XX -1
 
-## -----------------------------------------------------------------------------
+## -------------------------------------------------------------------
 ## An example with three independent AR(1)'s with separate means, but
 ## with the same hyperparameters. These are observed with three
 ## different likelihoods.
@@ -685,28 +695,28 @@ result = inla(formula, family = c("binomial", "poisson", "normal"),
                       list()))
 summary(result)
 
-## ----eval=FALSE---------------------------------------------------------------
+## ----eval=FALSE-----------------------------------------------------
 #  y ~ 1 + z
 
-## ----eval=FALSE---------------------------------------------------------------
+## ----eval=FALSE-----------------------------------------------------
 #  eta~ = A %*% eta
 
-## ----eval=FALSE---------------------------------------------------------------
+## ----eval=FALSE-----------------------------------------------------
 #  y ~ 1 + z, with addition matrix A
 
-## ----eval=FALSE---------------------------------------------------------------
+## ----eval=FALSE-----------------------------------------------------
 #  y    ~ eta~   ## no intercept...
 #  eta~ = A %*% eta
 #  eta  = intercept + beta*z
 
-## ----eval=FALSE---------------------------------------------------------------
+## ----eval=FALSE-----------------------------------------------------
 #  control.predictor=list(A=A)
 
-## ----eval=FALSE---------------------------------------------------------------
+## ----eval=FALSE-----------------------------------------------------
 #  eta~ = A %*% eta + offset.arg
 #  eta = intercept + beta*z + offset.formula
 
-## -----------------------------------------------------------------------------
+## -------------------------------------------------------------------
 ## 'm' is the number of observations of eta*, where eta* = A eta +
 ## offset.arg, and A is a fixed m x n matrix, and eta has length n. An
 ## offset in the formula goes into 'eta' whereas an offset in the
@@ -753,10 +763,10 @@ summary(r)
 ## this should be a small number
 print(max(abs(r$summary.linear.predictor$mean - c(Eta, eta))))
 
-## ----eval=FALSE---------------------------------------------------------------
+## ----eval=FALSE-----------------------------------------------------
 #  y = intercept + s[j] + 0.5*s[k] + noise
 
-## ----plot=TRUE----------------------------------------------------------------
+## ----plot=TRUE------------------------------------------------------
 n = 100
 s = c(-1, 0, 1)
 nS = length(s)
